pub struct EdgeFunctionV100Indices { /* private fields */ }Expand description
Auto-generated bindings for index of the exports of
edge-function-v100.
This is an implementation detail of EdgeFunctionV100Pre and can
be constructed if needed as well.
For more information see EdgeFunctionV100 as well.
Implementations
Sourceimpl EdgeFunctionV100Indices
impl EdgeFunctionV100Indices
Sourcepub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>
Creates a new copy of EdgeFunctionV100Indices bindings which can then
be used to instantiate into a particular store.
This method may fail if the component does not have the required exports.
Sourcepub fn load(
&self,
store: impl AsContextMut,
instance: &Instance,
) -> Result<EdgeFunctionV100>
pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<EdgeFunctionV100>
Uses the indices stored in self to load an instance
of EdgeFunctionV100 from the instance provided.
Note that at this time this method will additionally perform type-checks of all exports.